# PdfFieldFiller

PdfFieldFiller leverages the PyPDF2 library by
streamlining the ability to fill our a PDF form
fields by utilizing a configuration file.

## Examples

An example configuration file can be found in the 
`tests\etc`folder.


## Tests
PdfFieldFiller includes a test suite built on the 
unittest framework. All tests are located in the 
"tests" folder. Tests can be run from the command 
line by:

```bash
python -m unittest Tests.tests
```
